==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BlockChaosSpecFluent<A extends BlockChaosSpecFluent<A>> extends BaseFluent<A>{
  public BlockChaosSpecFluent() {
  }
  public BlockChaosSpecFluent(BlockChaosSpec instance) {
    instance = (instance != null ? instance : new BlockChaosSpec());

    if (instance != null) {
      this.withAction(instance.getAction());
      this.withContainerNames(instance.getContainerNames());
      this.withDelay(instance.getDelay());
      this.withDuration(instance.getDuration());
      this.withIops(instance.getIops());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withValue(instance.getValue());
      this.withVolumeName(instance.getVolumeName());
      this.withAction(instance.getAction());
      this.withContainerNames(instance.getContainerNames());
      this.withDelay(instance.getDelay());
      this.withDuration(instance.getDuration());
      this.withIops(instance.getIops());
      this.withMode(instance.getMode());
      this.withSelector(instance.getSelector());
      this.withValue(instance.getValue());
      this.withVolumeName(instance.getVolumeName());
    }
  }
  private String action;
  private List<String> containerNames = new ArrayList<String>();
  private BlockDelaySpecBuilder delay;
  private String duration;
  private Integer iops;
  private String mode;
  private PodSelectorSpecBuilder selector;
  private String value;
  private String volumeName;
  public String getAction() {
    return this.action;
  }
  public A withAction(String action) {
    this.action=action; return (A) this;
  }
  public boolean hasAction() {
    return this.action != null;
  }
  public A addToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.add(index, item);
    return (A)this;
  }
  public A setToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.set(index, item); return (A)this;
  }
  public A addToContainerNames(java.lang.String... items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  public A addAllToContainerNames(Collection<String> items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  public A removeFromContainerNames(java.lang.String... items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  public A removeAllFromContainerNames(Collection<String> items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  public List<String> getContainerNames() {
    return this.containerNames;
  }
  public String getContainerName(int index) {
    return this.containerNames.get(index);
  }
  public String getFirstContainerName() {
    return this.containerNames.get(0);
  }
  public String getLastContainerName() {
    return this.containerNames.get(containerNames.size() - 1);
  }
  public String getMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withContainerNames(List<String> containerNames) {
    if (containerNames != null) {this.containerNames = new ArrayList(); for (String item : containerNames){this.addToContainerNames(item);}} else { this.containerNames = null;} return (A) this;
  }
  public A withContainerNames(java.lang.String... containerNames) {
    if (this.containerNames != null) {this.containerNames.clear(); _visitables.remove("containerNames"); }
    if (containerNames != null) {for (String item :containerNames){ this.addToContainerNames(item);}} return (A) this;
  }
  public boolean hasContainerNames() {
    return containerNames != null && !containerNames.isEmpty();
  }
  public BlockDelaySpec buildDelay() {
    return this.delay!=null ?this.delay.build():null;
  }
  public A withDelay(BlockDelaySpec delay) {
    _visitables.get("delay").remove(this.delay);
    if (delay!=null){ this.delay= new BlockDelaySpecBuilder(delay); _visitables.get("delay").add(this.delay);} else { this.delay = null; _visitables.get("delay").remove(this.delay); } return (A) this;
  }
  public boolean hasDelay() {
    return this.delay != null;
  }
  public A withNewDelay(String correlation,String jitter,String latency) {
    return (A)withDelay(new BlockDelaySpec(correlation, jitter, latency));
  }
  public DelayNested<A> withNewDelay() {
    return new DelayNested(null);
  }
  public DelayNested<A> withNewDelayLike(BlockDelaySpec item) {
    return new DelayNested(item);
  }
  public DelayNested<A> editDelay() {
    return withNewDelayLike(java.util.Optional.ofNullable(buildDelay()).orElse(null));
  }
  public DelayNested<A> editOrNewDelay() {
    return withNewDelayLike(java.util.Optional.ofNullable(buildDelay()).orElse(new BlockDelaySpecBuilder().build()));
  }
  public DelayNested<A> editOrNewDelayLike(BlockDelaySpec item) {
    return withNewDelayLike(java.util.Optional.ofNullable(buildDelay()).orElse(item));
  }
  public String getDuration() {
    return this.duration;
  }
  public A withDuration(String duration) {
    this.duration=duration; return (A) this;
  }
  public boolean hasDuration() {
    return this.duration != null;
  }
  public Integer getIops() {
    return this.iops;
  }
  public A withIops(Integer iops) {
    this.iops=iops; return (A) this;
  }
  public boolean hasIops() {
    return this.iops != null;
  }
  public String getMode() {
    return this.mode;
  }
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  public boolean hasMode() {
    return this.mode != null;
  }
  public PodSelectorSpec buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(PodSelectorSpec selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodSelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public boolean hasSelector() {
    return this.selector != null;
  }
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  public String getValue() {
    return this.value;
  }
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  public boolean hasValue() {
    return this.value != null;
  }
  public String getVolumeName() {
    return this.volumeName;
  }
  public A withVolumeName(String volumeName) {
    this.volumeName=volumeName; return (A) this;
  }
  public boolean hasVolumeName() {
    return this.volumeName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BlockChaosSpecFluent that = (BlockChaosSpecFluent) o;
    if (!java.util.Objects.equals(action, that.action)) return false;

    if (!java.util.Objects.equals(containerNames, that.containerNames)) return false;

    if (!java.util.Objects.equals(delay, that.delay)) return false;

    if (!java.util.Objects.equals(duration, that.duration)) return false;

    if (!java.util.Objects.equals(iops, that.iops)) return false;

    if (!java.util.Objects.equals(mode, that.mode)) return false;

    if (!java.util.Objects.equals(selector, that.selector)) return false;

    if (!java.util.Objects.equals(value, that.value)) return false;

    if (!java.util.Objects.equals(volumeName, that.volumeName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(action,  containerNames,  delay,  duration,  iops,  mode,  selector,  value,  volumeName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (containerNames != null && !containerNames.isEmpty()) { sb.append("containerNames:"); sb.append(containerNames + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (iops != null) { sb.append("iops:"); sb.append(iops + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (volumeName != null) { sb.append("volumeName:"); sb.append(volumeName); }
    sb.append("}");
    return sb.toString();
  }
  public class DelayNested<N> extends BlockDelaySpecFluent<DelayNested<N>> implements Nested<N>{
    DelayNested(BlockDelaySpec item) {
      this.builder = new BlockDelaySpecBuilder(this, item);
    }
    BlockDelaySpecBuilder builder;
    public N and() {
      return (N) BlockChaosSpecFluent.this.withDelay(builder.build());
    }
    public N endDelay() {
      return and();
    }
    
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    public N and() {
      return (N) BlockChaosSpecFluent.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/BlockChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BlockChaosSpecFluent<A extends BlockChaosSpecFluent<A>> extends BaseFluent<A>{
  public BlockChaosSpecFluent() {
  }
  
  public BlockChaosSpecFluent(BlockChaosSpec instance) {
    this.copyInstance(instance);
  }
  private String action;
  private List<String> containerNames = new ArrayList<String>();
  private BlockDelaySpecBuilder delay;
  private String duration;
  private Integer iops;
  private String mode;
  private PodSelectorSpecBuilder selector;
  private String value;
  private String volumeName;
  
  protected void copyInstance(BlockChaosSpec instance) {
    instance = (instance != null ? instance : new BlockChaosSpec());
  
    if (instance != null) {
        this.withAction(instance.getAction());
        this.withContainerNames(instance.getContainerNames());
        this.withDelay(instance.getDelay());
        this.withDuration(instance.getDuration());
        this.withIops(instance.getIops());
        this.withMode(instance.getMode());
        this.withSelector(instance.getSelector());
        this.withValue(instance.getValue());
        this.withVolumeName(instance.getVolumeName());
        this.withAction(instance.getAction());
        this.withContainerNames(instance.getContainerNames());
        this.withDelay(instance.getDelay());
        this.withDuration(instance.getDuration());
        this.withIops(instance.getIops());
        this.withMode(instance.getMode());
        this.withSelector(instance.getSelector());
        this.withValue(instance.getValue());
        this.withVolumeName(instance.getVolumeName());
      }
  }
  
  public String getAction() {
    return this.action;
  }
  
  public A withAction(String action) {
    this.action=action; return (A) this;
  }
  
  public boolean hasAction() {
    return this.action != null;
  }
  
  public A addToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.add(index, item);
    return (A)this;
  }
  
  public A setToContainerNames(int index,String item) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    this.containerNames.set(index, item); return (A)this;
  }
  
  public A addToContainerNames(java.lang.String... items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A addAllToContainerNames(Collection<String> items) {
    if (this.containerNames == null) {this.containerNames = new ArrayList<String>();}
    for (String item : items) {this.containerNames.add(item);} return (A)this;
  }
  
  public A removeFromContainerNames(java.lang.String... items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public A removeAllFromContainerNames(Collection<String> items) {
    if (this.containerNames == null) return (A)this;
    for (String item : items) { this.containerNames.remove(item);} return (A)this;
  }
  
  public List<String> getContainerNames() {
    return this.containerNames;
  }
  
  public String getContainerName(int index) {
    return this.containerNames.get(index);
  }
  
  public String getFirstContainerName() {
    return this.containerNames.get(0);
  }
  
  public String getLastContainerName() {
    return this.containerNames.get(containerNames.size() - 1);
  }
  
  public String getMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingContainerName(Predicate<String> predicate) {
    for (String item: containerNames) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withContainerNames(List<String> containerNames) {
    if (containerNames != null) {this.containerNames = new ArrayList(); for (String item : containerNames){this.addToContainerNames(item);}} else { this.containerNames = null;} return (A) this;
  }
  
  public A withContainerNames(java.lang.String... containerNames) {
    if (this.containerNames != null) {this.containerNames.clear(); _visitables.remove("containerNames"); }
    if (containerNames != null) {for (String item :containerNames){ this.addToContainerNames(item);}} return (A) this;
  }
  
  public boolean hasContainerNames() {
    return containerNames != null && !containerNames.isEmpty();
  }
  
  public BlockDelaySpec buildDelay() {
    return this.delay!=null ?this.delay.build():null;
  }
  
  public A withDelay(BlockDelaySpec delay) {
    _visitables.get("delay").remove(this.delay);
    if (delay!=null){ this.delay= new BlockDelaySpecBuilder(delay); _visitables.get("delay").add(this.delay);} else { this.delay = null; _visitables.get("delay").remove(this.delay); } return (A) this;
  }
  
  public boolean hasDelay() {
    return this.delay != null;
  }
  
  public A withNewDelay(String correlation,String jitter,String latency) {
    return (A)withDelay(new BlockDelaySpec(correlation, jitter, latency));
  }
  
  public DelayNested<A> withNewDelay() {
    return new DelayNested(null);
  }
  
  public DelayNested<A> withNewDelayLike(BlockDelaySpec item) {
    return new DelayNested(item);
  }
  
  public DelayNested<A> editDelay() {
    return withNewDelayLike(java.util.Optional.ofNullable(buildDelay()).orElse(null));
  }
  
  public DelayNested<A> editOrNewDelay() {
    return withNewDelayLike(java.util.Optional.ofNullable(buildDelay()).orElse(new BlockDelaySpecBuilder().build()));
  }
  
  public DelayNested<A> editOrNewDelayLike(BlockDelaySpec item) {
    return withNewDelayLike(java.util.Optional.ofNullable(buildDelay()).orElse(item));
  }
  
  public String getDuration() {
    return this.duration;
  }
  
  public A withDuration(String duration) {
    this.duration=duration; return (A) this;
  }
  
  public boolean hasDuration() {
    return this.duration != null;
  }
  
  public Integer getIops() {
    return this.iops;
  }
  
  public A withIops(Integer iops) {
    this.iops=iops; return (A) this;
  }
  
  public boolean hasIops() {
    return this.iops != null;
  }
  
  public String getMode() {
    return this.mode;
  }
  
  public A withMode(String mode) {
    this.mode=mode; return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public PodSelectorSpec buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  
  public A withSelector(PodSelectorSpec selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new PodSelectorSpecBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  
  public boolean hasSelector() {
    return this.selector != null;
  }
  
  public SelectorNested<A> withNewSelector() {
    return new SelectorNested(null);
  }
  
  public SelectorNested<A> withNewSelectorLike(PodSelectorSpec item) {
    return new SelectorNested(item);
  }
  
  public SelectorNested<A> editSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(null));
  }
  
  public SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(new PodSelectorSpecBuilder().build()));
  }
  
  public SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item) {
    return withNewSelectorLike(java.util.Optional.ofNullable(buildSelector()).orElse(item));
  }
  
  public String getValue() {
    return this.value;
  }
  
  public A withValue(String value) {
    this.value=value; return (A) this;
  }
  
  public boolean hasValue() {
    return this.value != null;
  }
  
  public String getVolumeName() {
    return this.volumeName;
  }
  
  public A withVolumeName(String volumeName) {
    this.volumeName=volumeName; return (A) this;
  }
  
  public boolean hasVolumeName() {
    return this.volumeName != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BlockChaosSpecFluent that = (BlockChaosSpecFluent) o;
    if (!java.util.Objects.equals(action, that.action)) return false;
  
    if (!java.util.Objects.equals(containerNames, that.containerNames)) return false;
  
    if (!java.util.Objects.equals(delay, that.delay)) return false;
  
    if (!java.util.Objects.equals(duration, that.duration)) return false;
  
    if (!java.util.Objects.equals(iops, that.iops)) return false;
  
    if (!java.util.Objects.equals(mode, that.mode)) return false;
  
    if (!java.util.Objects.equals(selector, that.selector)) return false;
  
    if (!java.util.Objects.equals(value, that.value)) return false;
  
    if (!java.util.Objects.equals(volumeName, that.volumeName)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(action,  containerNames,  delay,  duration,  iops,  mode,  selector,  value,  volumeName,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (containerNames != null && !containerNames.isEmpty()) { sb.append("containerNames:"); sb.append(containerNames + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (duration != null) { sb.append("duration:"); sb.append(duration + ","); }
    if (iops != null) { sb.append("iops:"); sb.append(iops + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (value != null) { sb.append("value:"); sb.append(value + ","); }
    if (volumeName != null) { sb.append("volumeName:"); sb.append(volumeName); }
    sb.append("}");
    return sb.toString();
  }
  public class DelayNested<N> extends BlockDelaySpecFluent<DelayNested<N>> implements Nested<N>{
    DelayNested(BlockDelaySpec item) {
      this.builder = new BlockDelaySpecBuilder(this, item);
    }
    BlockDelaySpecBuilder builder;
    
    public N and() {
      return (N) BlockChaosSpecFluent.this.withDelay(builder.build());
    }
    
    public N endDelay() {
      return and();
    }
    
  
  }
  public class SelectorNested<N> extends PodSelectorSpecFluent<SelectorNested<N>> implements Nested<N>{
    SelectorNested(PodSelectorSpec item) {
      this.builder = new PodSelectorSpecBuilder(this, item);
    }
    PodSelectorSpecBuilder builder;
    
    public N and() {
      return (N) BlockChaosSpecFluent.this.withSelector(builder.build());
    }
    
    public N endSelector() {
      return and();
    }
    
  
  }

}
